setShowCompassOnRotate method

Future<void> setShowCompassOnRotate(
  1. bool show
)

Set the visibility of the compass on the map

show true to show the compass when rotating the screen away from north, false to hide it

The compass is shown by default

Implementation

Future<void> setShowCompassOnRotate(bool show) {
  return MapcontrolPlatform.instance.showCompassOnRotate(show);
}